@@ -91,15 +91,15 @@ plot.bootdistcens <- function(x,...){
         stop("Use only with 'bootdistcens' objects")
     if (dim(x$estim)[2]==1) {
         stripchart(x$estim,method="jitter",
-        xlab="Boostrapped values of the parameter",...)
+        xlab="Bootstrapped values of the parameter",...)
     }
     else {
         if (dim(x$estim)[2]==2)
             plot(x$estim,
-            main="Boostrapped values of the two parameters",...)
+            main="Bootstrapped values of the two parameters",...)
         else 
             plot(x$estim,
-            main="Boostrapped values of parameters",...)
+            main="Bootstrapped values of parameters",...)
     }
 }
 
