@@ -22,7 +22,7 @@
 ###         R functions
 ### 
 
-plotdistcens <- function(censdata,distr,para,leftNA=-Inf,rightNA=Inf,...){
+plotdistcens <- function(censdata,distr,para,leftNA=-Inf,rightNA=Inf,Turnbull=TRUE,...){
     def.par <- par(no.readonly = TRUE)
     if (missing(censdata) ||
         !(is.vector(censdata$left) & is.vector(censdata$right) & length(censdata[,1])>1))
@@ -31,62 +31,77 @@ plotdistcens <- function(censdata,distr,para,leftNA=-Inf,rightNA=Inf,...){
     if ((missing(distr) & !missing(para)) || 
     (missing(distr) & !missing(para)))
         stop("distr and para must defined")
-    if (is.finite(leftNA) & any(is.na(censdata$left)))
-        censdata[is.na(censdata$left),]$left<-leftNA
-    if (is.finite(rightNA) & any(is.na(censdata$right)))
-        censdata[is.na(censdata$right),]$right<-rightNA
-    lcens<-censdata[is.na(censdata$left),]$right
-    if (any(is.na(lcens)) )
-        stop("An observation cannot be both right and left censored, coded with two NA values")
-    rcens<-censdata[is.na(censdata$right),]$left
-    noricens<-censdata[!is.na(censdata$left) & !is.na(censdata$right),]
-    # definition of mid point for each observation (if not NA) 
-    # in order to have the order of plot of each observation
-    # and order of left and rigth bounds for censored observations
-    midnoricens<-(noricens$left+noricens$right)/2
-    ordmid<-order(midnoricens)
-    ordlcens<-order(lcens)
-    ordrcens<-order(rcens)
-    nlcens<-length(lcens)
-    nrcens<-length(rcens)
-    nnoricens<-length(noricens$left)
-    n<-length(censdata$left)
-    # definition of xlim 
-    xminright<-min(censdata[!is.na(censdata$right),]$right)
-    xminleft<-min(censdata[!is.na(censdata$left),]$left)
-    xmin=min(xminright,xminleft)
-    xmaxright<-max(censdata[!is.na(censdata$right),]$right)
-    xmaxleft<-max(censdata[!is.na(censdata$left),]$left)
-    xmax=max(xmaxright,xmaxleft)
-    xrange<-xmax-xmin
-    xmin<-xmin-0.3*xrange
-    xmax<-xmax+0.3*xrange
-    xlim<-c(xmin,xmax)
-    plot(c(0,0),c(0,0),type="n",xlim=xlim,ylim=c(0,1),xlab="censored data",
-    ylab="CDF",main="Cumulative distribution")
-    # functions to plot one interval or point for each observation for 
-    # observation ordered i out of n
-    plotlcens<-function(i) {
-        y<-i/n
-        lines(c(xmin,lcens[ordlcens[i]]),c(y,y))
+        
+    if (Turnbull)
+    {
+        survdata <- Surv(time = censdata$left, time2 = censdata$right, type="interval2")
+        survfitted <- survfit(survdata ~ 1)
+        plot(survfitted,fun="event",xlab="censored data",
+        ylab="CDF",main="Cumulative distribution",...)
+        xmin <- par("usr")[1]
+        xmax <- par("usr")[2]
     }
-    if (nlcens>=1)
-        toto<-sapply(1:nlcens,plotlcens)
-    plotnoricens<-function(i) {
-        y<-(i+nlcens)/n
-        if (noricens[ordmid[i],]$left!=noricens[ordmid[i],]$right)
-            lines(c(noricens[ordmid[i],]$left,noricens[ordmid[i],]$right),c(y,y))
-        else
-            points(noricens[ordmid[i],]$left,y,pch=4)
-    }
-    if (nnoricens>=1)
-        toto<-sapply(1:nnoricens,plotnoricens)
-    plotrcens<-function(i) {
-        y<-(i+nlcens+nnoricens)/n
-        lines(c(rcens[ordrcens[i]],xmax),c(y,y))
-    }
-    if (nrcens>=1)
-        toto<-sapply(1:nrcens,plotrcens)
+    
+   
+    else
+    {    
+        if (is.finite(leftNA) & any(is.na(censdata$left)))
+            censdata[is.na(censdata$left),]$left<-leftNA
+        if (is.finite(rightNA) & any(is.na(censdata$right)))
+            censdata[is.na(censdata$right),]$right<-rightNA
+        lcens<-censdata[is.na(censdata$left),]$right
+        if (any(is.na(lcens)) )
+            stop("An observation cannot be both right and left censored, coded with two NA values")
+        rcens<-censdata[is.na(censdata$right),]$left
+        noricens<-censdata[!is.na(censdata$left) & !is.na(censdata$right),]
+        # definition of mid point for each observation (if not NA) 
+        # in order to have the order of plot of each observation
+        # and order of left and rigth bounds for censored observations
+        midnoricens<-(noricens$left+noricens$right)/2
+        ordmid<-order(midnoricens)
+        ordlcens<-order(lcens)
+        ordrcens<-order(rcens)
+        nlcens<-length(lcens)
+        nrcens<-length(rcens)
+        nnoricens<-length(noricens$left)
+        n<-length(censdata$left)
+        # definition of xlim 
+        xminright<-min(censdata[!is.na(censdata$right),]$right)
+        xminleft<-min(censdata[!is.na(censdata$left),]$left)
+        xmin=min(xminright,xminleft)
+        xmaxright<-max(censdata[!is.na(censdata$right),]$right)
+        xmaxleft<-max(censdata[!is.na(censdata$left),]$left)
+        xmax=max(xmaxright,xmaxleft)
+        xrange<-xmax-xmin
+        xmin<-xmin-0.3*xrange
+        xmax<-xmax+0.3*xrange
+        xlim<-c(xmin,xmax)
+        plot(c(0,0),c(0,0),type="n",xlim=xlim,ylim=c(0,1),xlab="censored data",
+        ylab="CDF",main="Cumulative distribution",...)
+        # functions to plot one interval or point for each observation for 
+        # observation ordered i out of n
+        plotlcens<-function(i) {
+            y<-i/n
+            lines(c(xmin,lcens[ordlcens[i]]),c(y,y))
+        }
+        if (nlcens>=1)
+            toto<-sapply(1:nlcens,plotlcens)
+        plotnoricens<-function(i) {
+            y<-(i+nlcens)/n
+            if (noricens[ordmid[i],]$left!=noricens[ordmid[i],]$right)
+                lines(c(noricens[ordmid[i],]$left,noricens[ordmid[i],]$right),c(y,y))
+            else
+                points(noricens[ordmid[i],]$left,y,pch=4)
+        }
+        if (nnoricens>=1)
+            toto<-sapply(1:nnoricens,plotnoricens)
+        plotrcens<-function(i) {
+            y<-(i+nlcens+nnoricens)/n
+            lines(c(rcens[ordrcens[i]],xmax),c(y,y))
+        }
+        if (nrcens>=1)
+            toto<-sapply(1:nrcens,plotrcens)
+    } # else if Turnbull
     
     if (!missing(distr)){ # plot of the theoretical cumulative function
         if (!is.character(distr)) distname<-substring(as.character(match.call()$distr),2)
@@ -109,7 +124,7 @@ plotdistcens <- function(censdata,distr,para,leftNA=-Inf,rightNA=Inf,...){
         # plot of continuous data with theoretical distribution
         s<-seq(xmin,xmax,by=(xmax-xmin)/100)
         theop<-do.call(pdistname,c(list(q=s),as.list(para)))
-        lines(s,theop,lty=1)
+        lines(s,theop,...)
      }
     par(def.par)    
     
